@@ -781,6 +781,7 @@ eel_open_with_dialog_instance_init (EelOpenWithDialog *dialog)
 {
 	GtkWidget *hbox;
 	GtkWidget *vbox;
+	GtkWidget *vbox2;
 	GtkWidget *label;
 	GtkWidget *align;
 	GtkWidget *scrolled_window;
@@ -791,23 +792,28 @@ eel_open_with_dialog_instance_init (EelOpenWithDialog *dialog)
 
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Open With"));
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
-	gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
+	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
 
 	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 2);
 
-	vbox = gtk_vbox_new (FALSE, 6);
+	vbox = gtk_vbox_new (FALSE, 12);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
+
+	vbox2 = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (vbox), vbox2, TRUE, TRUE, 0);
+
 	dialog->details->label = gtk_label_new ("");
 	gtk_misc_set_alignment (GTK_MISC (dialog->details->label), 0.0, 0.5);
 	gtk_label_set_line_wrap (GTK_LABEL (dialog->details->label), TRUE);
-	gtk_box_pack_start (GTK_BOX (vbox), dialog->details->label,
+	gtk_box_pack_start (GTK_BOX (vbox2), dialog->details->label,
 			    FALSE, FALSE, 0);
 	gtk_widget_show (dialog->details->label);
 
 
 	scrolled_window = gtk_scrolled_window_new (NULL, NULL);
-	gtk_widget_set_size_request (scrolled_window, 400, 400);
+	gtk_widget_set_size_request (scrolled_window, 400, 300);
 	
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled_window),
 					     GTK_SHADOW_IN);
@@ -819,14 +825,14 @@ eel_open_with_dialog_instance_init (EelOpenWithDialog *dialog)
 					   FALSE);
 	gtk_container_add (GTK_CONTAINER (scrolled_window), dialog->details->program_list);
 	
-	gtk_box_pack_start (GTK_BOX (vbox), scrolled_window, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox2), scrolled_window, TRUE, TRUE, 0);
 
 	dialog->details->desc_label = gtk_label_new (_("Select an application to view its description."));
 	gtk_misc_set_alignment (GTK_MISC (dialog->details->desc_label), 0.0, 0.5);
 	gtk_label_set_justify (GTK_LABEL (dialog->details->desc_label), GTK_JUSTIFY_LEFT);
 	gtk_label_set_line_wrap (GTK_LABEL (dialog->details->desc_label), TRUE);
 	gtk_label_set_single_line_mode (GTK_LABEL (dialog->details->desc_label), FALSE);
-	gtk_box_pack_start (GTK_BOX (vbox), dialog->details->desc_label, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox2), dialog->details->desc_label, FALSE, FALSE, 0);
 	
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (dialog->details->program_list));
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
@@ -846,9 +852,8 @@ eel_open_with_dialog_instance_init (EelOpenWithDialog *dialog)
 	gtk_widget_show_all (vbox);
 
 
-	expander = gtk_expander_new_with_mnemonic (_("Use a _custom command"));
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), expander,
-			    FALSE, FALSE, 0);
+	expander = gtk_expander_new_with_mnemonic (_("_Use a custom command"));
+	gtk_box_pack_start (GTK_BOX (vbox), expander, FALSE, FALSE, 0);
 	g_signal_connect_after (expander, "activate", G_CALLBACK (expander_toggled), dialog);
 
 	gtk_widget_show (expander);
